@@ -20,7 +20,14 @@
 
 */
 
-require_once('/usr/share/php-getid3/getid3.php');
+if (file_exists('/usr/share/php-getid3/getid3.php')) {
+	require_once('/usr/share/php-getid3/getid3.php');
+} elseif (file_exists('/usr/share/php/getid3/getid3.php')) {
+	require_once('/usr/share/php/getid3/getid3.php');
+} else {
+	print("Required PHP module getid3 is not installed");
+	exit(1);
+}
 
 /* A list of file formats we will recognize */
 $FORMATS = array("mp3", "m4a", "oga", "ogg", "wav", "flac");
@@ -175,7 +182,7 @@ body {font-size: 13px; font-family: verdana,arial,helvetica,sans-serif; font-wei
 <link rel="shortcut icon" href="/musica/favicon.ico" type="image/x-icon">
 </head>
 
-<?
+<?php
 }
 
 /*****************/
@@ -229,25 +236,20 @@ function get_all_albums($search="") {
 }
 
 function get_all_songs($search="") {
-	$songs = @file("/var/lib/musica/songs");
+	$all_songs = @file("/var/lib/musica/songs");
 	if ($search) {
 		if ($search == "_random_") {
-			$song = $songs[rand(0, sizeof($songs) - 1)];
-			$songs = array($song);
-			list($artist, $album, $song) = split3($song);
-			print("
-				<script>
-					parent._artists.location.href='?search=" . urlencode($artist) . "&artist=_all';
-					parent._albums.location.href='?search=" . urlencode($album) . "&artist=_search&album=_search';
-				</script>
-			");
-			print_song_header($artist, $album, $search);
+			$songs = array();
+			for ($i=0; $i<200; $i++) {
+				$song = $all_songs[rand(0, sizeof($all_songs) - 1)];
+				array_push($songs, $song);
+			}
+			print_song_header("Random Artists", "Random Albums", $search);
 		} else {
 			$str = preg_escape($search);
-			$songs = array_rtrim(preg_grep("/.*\/.*\/.*$str/i", $songs));
+			$songs = array_rtrim(preg_grep("/.*\/.*\/.*$str/i", $all_songs));
 		}
 	}
-	$songs = array_rtrim($songs);
 	return $songs;
 }
 
